@@ -177,7 +177,7 @@ def dist_towers(towers, location):
         d_towers.append(dist(d,False,tower))
     return d_towers
 
-def intersect(p1,p2,p3,p4,eps):
+def intersect(p1,p2,p3,p4,eps,no_tu=True):
     d = (p1[0]-p2[0])*(p3[1]-p4[1])-(p1[1]-p2[1])*(p3[0]-p4[0])
     if d == 0:
         return None
@@ -189,7 +189,7 @@ def intersect(p1,p2,p3,p4,eps):
         return None
     x = ((p1[0]*p2[1]-p1[1]*p2[0])*(p3[0]-p4[0])-(p1[0]-p2[0])*(p3[0]*p4[1]-p3[1]*p4[0]))/d
     y = ((p1[0]*p2[1]-p1[1]*p2[0])*(p3[1]-p4[1])-(p1[1]-p2[1])*(p3[0]*p4[1]-p3[1]*p4[0]))/d
-    return x,y
+    return (x,y) if no_tu else (x,y),(t,u)
         
 def find_all_neighbours(tower, around, eps, safe_dist, minusid, latlon2id, penalty):
     #from util import verbosity
