@@ -51,6 +51,7 @@ def render(g,nodes,edges,file_name_out,markers=False,lines=False,host="localhost
     from binascii import hexlify
     from pathlib import Path
     from math import log2
+    from pkg_resources import resource_string
     start("Rendering graph")
     min_lat = min_long = float('inf')
     max_lat = max_long = -float('inf')
@@ -68,7 +69,7 @@ def render(g,nodes,edges,file_name_out,markers=False,lines=False,host="localhost
     if lines:
         for u,v,weight in edges:
             PolyLine([u[1:3],v[1:3]],color="#3f3f00",opacity=0.4,weight=6,tooltip=("weight: %.1f" % weight)).add_to(m)
-    TEMPLATE = open("limic/render.js").read()
+    TEMPLATE = resource_string("limic","render.js").decode('utf8')
     from branca.element import MacroElement, Template
     class LatLngListener(MacroElement):
         _template = Template(TEMPLATE % {'host':host,'port':port,'prefix':prefix})
